@@ -29,7 +29,8 @@ enum {
 	AID_SOUND,
 	AID_VOLUME,
 	AID_APPLYAUDIO,
-	AID_APPLYTHEMEMODE
+	AID_APPLYTHEMEMODE,
+	AID_AUTOSHIFT
 };
 
 class Menu;
